pitchtools.all_are_chromatic_pitch_class_name_octave_number_pairs
=================================================================

.. autofunction:: abjad.tools.pitchtools.all_are_chromatic_pitch_class_name_octave_number_pairs.all_are_chromatic_pitch_class_name_octave_number_pairs
